.. moniplot documentation master file, created by
   sphinx-quickstart on Wed Sep 28 10:51:14 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Moniplot User Manual
====================

.. _matplotlib: https://matplotlib.org
.. _xarray: https://docs.xarray.dev/en/stable/

Moniplot is a Python data visualization library based on matplotlib_
and xarray_.
It provides a high-level interface for drawing attractive and informative
graphics for onground calibration data analysis or inflight instrument
monitoring.

Quick-start
-----------

.. toctree::
    :maxdepth: 1

    quick
    build

Module Documentation
--------------------

.. toctree::
   :maxdepth: 2

   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
